@@ -5,7 +5,6 @@ import aiohttp
 from typing import List
 import typing
 from .helpers import funcs
-import json
 from emoji import UNICODE_EMOJI
 
 def Validator(qtype: str):
@@ -15,12 +14,12 @@ def Validator(qtype: str):
         raise InvalidFormType(f'Type {qtype} is invalid!')
 
 class FormResponse:
-    def __init__(self,data:dict) -> None:
-        for d in data.keys():
-            if isinstance(data[d], dict):
-                setattr(self,d,data[d]['res'])
+    def __init__(self, data: list) -> None:
+        for d in data:
+            if isinstance(data[data.index(d)], dict):
+                setattr(self, d['key'], data[data.index(d)]['res'])
             else:
-                setattr(self,d,data[d])
+                setattr(self, d['key'], data[d])
 
 class Form:
     """The basic form object.
@@ -37,7 +36,7 @@ class Form:
     def __init__(self, ctx:commands.Context, title, cleanup=False):
         self._ctx = ctx
         self._bot = ctx.bot
-        self._questions = {}
+        self._questions = []
         self.title = title
         self.timeout = 120
         self.editanddelete = False
@@ -48,7 +47,7 @@ class Form:
         self.cancelkeywords = ['cancel', 'stop', 'quit']
         self.cleanup = cleanup
 
-    def set_timeout(self,timeout:int) -> None:
+    def set_timeout(self, timeout:int) -> None:
         """Sets the timeout for the form.
 
         Parameters
@@ -58,7 +57,7 @@ class Form:
         """
         self.timeout = timeout
 
-    def set_tries(self,tries:int) -> None:
+    def set_tries(self, tries:int) -> None:
         """Set the amount of tries that are allowed during input validation. Defaults to 3.
 
         Parameters
@@ -96,7 +95,7 @@ class Form:
     def add_question(self, question, key:str=None, qtype: List[typing.Union[Validator, typing.Callable]] = []) -> List[dict]:
         """Adds a question to the form.
         The valid qtypes are:
-        `invite`,`channel`,`user`,`member`,`role`, and `category`
+        `invite`, `channel`, `user`, `member`, `role`, and `category`
 
         Parameters
         ----------
@@ -125,20 +124,22 @@ class Form:
             qtype = [qtype]
         if not key:
             key = question
-        dictionary = {'res':None,'question':question}
+
+        dictionary = {'res':None, 'question':question}
         print(dictionary)
         dictionary['type'] = qtype
+        dictionary['key'] = key
         print(dictionary)
         self._tries = 3
 
-        self._questions[key] = dictionary
+        self._questions.append(dictionary)
         print(self._questions)
         self.set_incorrect_message('You answered incorrectly too many times. Please try again.')
         self.set_retry_message(f'Please try again.')
         print('-------------------------------------------')
         return self._questions
 
-    def edit_and_delete(self,choice:bool=None) -> bool:
+    def edit_and_delete(self, choice:bool=None) -> bool:
         """Toggles the edit and delete feature.
 
         Parameters
@@ -161,7 +162,7 @@ class Form:
         else:
             self.editanddelete = choice
 
-    def set_retry_message(self,message:str):
+    def set_retry_message(self, message:str):
         """Sets the message to send if input validation fails.
 
         Parameters
@@ -171,7 +172,7 @@ class Form:
         """
         self._retrymsg = message
 
-    def set_incorrect_message(self,message:str):
+    def set_incorrect_message(self, message:str):
         """Sets the message to send if input validation fails and there are no more tries left..
 
         Parameters
@@ -181,18 +182,18 @@ class Form:
         """
         self._incorrectmsg = message
 
-    async def set_color(self,color:str) -> None:
+    async def set_color(self, color:str) -> None:
         """Sets the color of the form embeds."""
         match = re.match(r'(0x|#)(\d|(f|F|d|D|a|A|c|C|E|e|b|B)){6}', str(color))
         if not match:
             raise InvalidColor(f"{color} is invalid. Be sure to use colors such as '0xffffff'")
         if color.startswith("#"):
-            newclr = color.replace("#","")
+            newclr = color.replace("#", "")
             color = f"0x{newclr}"
-        color = await commands.ColourConverter().convert(self._ctx,color)
+        color = await commands.ColourConverter().convert(self._ctx, color)
         self.color = color
 
-    async def start(self,channel=None) -> dict:
+    async def start(self, channel=None) -> dict:
         """Starts the form in the current channel.
 
         Parameters
@@ -214,10 +215,10 @@ class Form:
             channel = self._ctx.channel
 
         qlist = []
-        for n, q in enumerate(self._questions.values()):
-            embed=discord.Embed(description=q['question'],color=self.color)
+        for n, q in enumerate(self._questions):
+            embed=discord.Embed(description=q['question'], color=self.color)
 
-            embed.set_author(name=f"{self.title}: {n+1}/{len(self._questions)}",icon_url=self._bot.user.avatar_url)
+            embed.set_author(name=f"{self.title}: {n+1}/{len(self._questions)}", icon_url=self._bot.user.avatar_url)
 
             if self.color:
                 embed.color=self.color
@@ -241,12 +242,12 @@ class Form:
             def check(m):
                 return m.channel == prompt.channel and m.author == self._ctx.author
             question = None
-            for x in self._questions.keys():
-                if self._questions[x]['question'].lower() == embed.description.lower():
+            for x in self._questions:
+                if self._questions[self._questions.index(x)]['question'].lower() == embed.description.lower():
                     question = x
-                    nx = self._questions[x]
+                    nx = self._questions[self._questions.index(x)]
             while True:
-                msg = await self._bot.wait_for('message',check=check,timeout=self.timeout)
+                msg = await self._bot.wait_for('message', check=check, timeout=self.timeout)
                 ans = msg.content
                 if ans.lower() in self.cancelkeywords:
                     if self.cleanup:
@@ -259,8 +260,8 @@ class Form:
                 if self.editanddelete:
                     await msg.delete()
                 key = question
-                if 'type' in self._questions[question].keys():
-                    qinfo = self._questions[question]
+                if 'type' in self._questions[self._questions.index(question)].keys():
+                    qinfo = self._questions[self._questions.index(question)]
                     print(self._questions)
                     for func in qinfo['type']:
                         correct = False
@@ -279,16 +280,24 @@ class Form:
                             print('else')
                             nx = qinfo
                             nx['res'] = result
-                            self._questions[key] = nx
+                            for n, i in enumerate(self._questions):
+                                if (i) == (key):
+                                    self._questions[n] = nx
                             correct=True
+                    if len(qinfo['type']) == 0:
+                        nx = qinfo
+                        nx['res'] = ans
+                        for n, i in enumerate(self._questions):
+                            if (i) == (key):
+                                self._questions[n] = nx
                 else:
-                    nx['res'] = ans
-                    self._questions[key] = nx
+                    nx['res'] = msg.content
+                    self._questions[self._questions.index(question)] = nx
                     break
                 if correct:
                     break
-        for i in self._questions.keys():
-            self._questions[i] = self._questions[i]
+        # for i in self._questions.keys():
+        #     self._questions[i] = self._questions[i]
         if self.cleanup:
             try:
                 await msg.delete()
@@ -301,7 +310,7 @@ class Form:
 class MissingRequiredArgument(Exception):
     pass
 
-class NaiveForm:
+class NaiveForm(Form):
     """The basic form object with naive validation. Should be used in scenarios where there is no context, such as reactions.
 
     Parameters:
@@ -323,59 +332,15 @@ class NaiveForm:
         self.editanddelete = False
         self.color = 0x2F3136
         self._incorrectmsg = None
-        self._retrymsg = None
+        self._retrymsg = "You have answered incorrectly"
         self._tries = None
         self.cancelkeywords = ['cancel', 'stop', 'quit']
         self.cleanup=cleanup
 
-    def enable_cancelkeywords(self, enabled: bool):
-        """Enables or disables the cancellation of the form.
-
-        Parameters
-        ----------
-        enabled : bool
-            Whether the form is enabled or disabled.
-        """
-        if enabled:
-            self.cancelkeywords = ['cancel', 'stop', 'quit']
-        else:
-            self.cancelkeywords = []
-
-    def add_cancelkeyword(self, word: str):
-        """Adds a word that will cancel the form.
-
-        Parameters
-        ----------
-        word : str
-            The word to listen for.
-        """
-        self.cancelkeywords.append(word.lower())
-
-    def set_timeout(self,timeout:int) -> None:
-        """Sets the timeout for the form.
-
-        Parameters
-        ----------
-
-            timeout (int): The timeout to be used.
-        """
-        self.timeout = timeout
-
-    def set_tries(self,tries:int) -> None:
-        """Set the amount of tries that are allowed during input validation. Defaults to 3.
-
-        Parameters
-        ----------
-        tries : int
-            The number of tries to set.
-        """
-        int(tries)
-        self._tries = tries
-
-    def add_question(self,question,key:str=None,qtype=None) -> List[dict]:
+    def add_question(self, question, key:str=None, qtype=None) -> List[dict]:
         """Adds a question to the form.
         The valid qtypes are:
-        `invite`,`channel`,`member`,`role`, and `emoji`
+        `invite`, `channel`, `member`, `role`, and `emoji`
 
         Parameters
         ----------
@@ -402,8 +367,8 @@ class NaiveForm:
         """
         if not key:
             key = question
-        valid_qtypes = ['invite','channel', 'member', 'role', 'category', 'emoji', 'file']
-        dictionary = {'res':None,'question':question}
+        valid_qtypes = ['invite', 'channel', 'member', 'role', 'category', 'emoji', 'file']
+        dictionary = {'res':None, 'question':question}
         if qtype:
             dictionary['type'] = None
             if qtype.lower() not in valid_qtypes:
@@ -416,7 +381,7 @@ class NaiveForm:
         self.set_retry_message(f'Please try again.')
         return self._questions
 
-    async def __validate_input(self,qtype,message):
+    async def __validate_input(self, qtype, message):
         answer = message.content
         if qtype.lower() == 'invite':
             async with aiohttp.ClientSession() as session:
@@ -438,57 +403,12 @@ class NaiveForm:
         else:
             raise InvalidFormType(f"Type '{qtype}' is invalid!")
 
-
-    def edit_and_delete(self,choice:bool=None) -> bool:
-        """Toggles the edit and delete feature.
-
-        Parameters
-        ----------
-        choice : bool, optional
-            Whether you want the bot to edit the prompt and delete the input or not. If none, it toggles. The default for edit and delete is off. Default input is `None`
-
-        Returns
-        -------
-        bool
-            The state of edit and delete (after this is completed)
-        """
-        if choice == None:
-            if self.editanddelete == True:
-                self.editanddelete = False
-                return False
-            else:
-                self.editanddelete = True
-                return True
-        else:
-            self.editanddelete = choice
-
-    def set_retry_message(self,message:str):
-        """Sets the message to send if input validation fails.
-
-        Parameters
-        ----------
-        message : str
-            The message to be set.
-        """
-        self._retrymsg = message
-
-    def set_incorrect_message(self,message:str):
-        """Sets the message to send if input validation fails and there are no more tries left..
-
-        Parameters
-        ----------
-        message : str
-            The message to be set.
-        """
-        self._incorrectmsg = message
-
-
-    async def set_color(self,color:str) -> None:
+    async def set_color(self, color:str) -> None:
         """Sets the color of the form embeds."""
         if isinstance(color, discord.Color): self.color = color
         else: raise InvalidColor("This color is invalid! It should be a `discord.Color` instance.")
 
-    async def start(self,channel=None) -> dict:
+    async def start(self, channel=None) -> dict:
         """Starts the form in the current channel.
 
         Parameters
@@ -509,20 +429,14 @@ class NaiveForm:
         if not channel:
             channel = self._channel
 
-        qlist = []
         for n, q in enumerate(self._questions.values()):
-            embed=discord.Embed(description=q['question'],color=self.color)
-
-            embed.set_author(name=f"{self.title}: {n+1}/{len(self._questions)}",icon_url=self._bot.user.avatar_url)
-
+            embed=discord.Embed(description=q['question'], color=self.color)
+            embed.set_author(name=f"{self.title}: {n+1}/{len(self._questions)}", icon_url=self._bot.user.avatar_url)
             if self.color:
                 embed.color=self.color
-
             elist.append(embed)
 
-
         prompt = None
-
         for embed in elist:
             ot = self._tries
             if self.editanddelete:
@@ -542,7 +456,7 @@ class NaiveForm:
                     question = x
                     nx = self._questions[x]
             while True:
-                msg = await self._bot.wait_for('message',check=check,timeout=self.timeout)
+                msg = await self._bot.wait_for('message', check=check, timeout=self.timeout)
                 ans = msg.content
                 if ans.lower() in self.cancelkeywords:
                     if self.cleanup:
@@ -555,6 +469,7 @@ class NaiveForm:
                 if self.editanddelete:
                     await msg.delete()
                 key = question
+                self._questions[question]['res'] = ans
                 if 'type' in self._questions[question].keys():
                     qinfo = self._questions[question]
                     print(self._questions)
